Package 'pcFactorStan'

Title: Stan Models for the Paired Comparison Factor Model
Description: Provides convenience functions and pre-programmed Stan models related to the paired comparison factor model. Its purpose is to make fitting paired comparison data using Stan easy. This package is described in Pritikin (2020) <doi:10.1016/j.heliyon.2020.e04821>.
Authors: Joshua N. Pritikin [aut, cre] (ORCID: <https://orcid.org/0000-0002-9862-5484>), Daniel C. Furr [ctb], Trustees of Columbia University [cph]
Maintainer: Joshua N. Pritikin <[email protected]>
License: GPL (>= 3)
Version: 1.5.4
Built: 2026-05-11 09:36:10 UTC
Source: https://github.com/jpritikin/pcfactorstan

Help Index